@@ -1,4 +1,6 @@
 """CMSPlugins for the cmsplugin_accordion app."""
+from django.utils.translation import ugettext_lazy as _
+
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 
@@ -7,9 +9,10 @@ from . import admin
 
 
 class AccordionPlugin(CMSPluginBase):
-    model = models.AccordionPlugin
-    render_template = "cmsplugin_accordion/accordion_plugin.html"
     inlines = [admin.AccordionRowInline, ]
+    model = models.AccordionPlugin
+    name = _('Accordion Plugin')
+    render_template = "cmsplugin_accordion/accordion_plugin.html"
 
     def render(self, context, instance, placeholder):
         context['instance'] = instance
