@@ -4,13 +4,6 @@ from django.test import TestCase
 from . import factories
 
 
-class AccordionTestCase(TestCase):
-    """Tests for the ``Accordion`` model class."""
-    def test_model(self):
-        obj = factories.AccordionFactory()
-        self.assertTrue(obj.pk)
-
-
 class AccordionRowTestCase(TestCase):
     """Tests for the ``AccordionRow`` model class."""
     def test_model(self):
@@ -21,5 +14,5 @@ class AccordionRowTestCase(TestCase):
 class AccordionPluginModelTestCase(TestCase):
     """Tests for the ``AccordionPluginModel`` model class."""
     def test_model(self):
-        obj = factories.AccordionPluginModel()
+        obj = factories.AccordionPluginFactory()
         self.assertTrue(obj.pk)
